pub type ValkeyCommand = Cmd;Expand description
A Valkey command whose response is decoded by crate::ValkeyConnector.
Aliased Type
pub struct ValkeyCommand { /* private fields */ }pub type ValkeyCommand = Cmd;A Valkey command whose response is decoded by crate::ValkeyConnector.
pub struct ValkeyCommand { /* private fields */ }